@@ -4,6 +4,7 @@ import (
 	"testing"
 
 	v1 "github.com/openshift/api/operator/v1"
+	corev1 "k8s.io/api/core/v1"
 
 	"github.com/openshift/console-operator/pkg/api"
 
@@ -51,6 +52,7 @@ func TestConsoleServerCLIConfigBuilder(t *testing.T) {
 					APIServerURL("https://foobar.com/api").
 					Host("https://foobar.com/host").
 					LogoutURL("https://foobar.com/logout").
+					DefaultIngressCert(false).
 					Config()
 			},
 			output: Config{
@@ -69,7 +71,54 @@ func TestConsoleServerCLIConfigBuilder(t *testing.T) {
 				Auth: Auth{
 					ClientID:            api.OpenShiftConsoleName,
 					ClientSecretFile:    clientSecretFilePath,
-					OAuthEndpointCAFile: oauthEndpointCAFilePath,
+					OAuthEndpointCAFile: defaultIngressCertFilePath,
+					LogoutRedirect:      "https://foobar.com/logout",
+				},
+				Customization: Customization{},
+				Providers:     Providers{},
+			},
+		}, {
+			name: "Config builder should handle monitoring and info",
+			input: func() Config {
+				b := &ConsoleServerCLIConfigBuilder{}
+				return b.
+					APIServerURL("https://foobar.com/api").
+					Host("https://foobar.com/host").
+					LogoutURL("https://foobar.com/logout").
+					Monitoring(&corev1.ConfigMap{
+						Data: map[string]string{
+							"alertmanagerPublicURL": "https://alertmanager.url.com",
+							"grafanaPublicURL":      "https://grafana.url.com",
+							"prometheusPublicURL":   "https://prometheus.url.com",
+							"thanosPublicURL":       "https://thanos.url.com",
+						},
+					}).
+					DefaultIngressCert(false).
+					Config()
+			},
+			output: Config{
+				Kind:       "ConsoleConfig",
+				APIVersion: "console.openshift.io/v1",
+				ServingInfo: ServingInfo{
+					BindAddress: "https://[::]:8443",
+					CertFile:    certFilePath,
+					KeyFile:     keyFilePath,
+				},
+				ClusterInfo: ClusterInfo{
+					ConsoleBasePath:    "",
+					ConsoleBaseAddress: "https://foobar.com/host",
+					MasterPublicURL:    "https://foobar.com/api",
+				},
+				MonitoringInfo: MonitoringInfo{
+					AlertmanagerPublicURL: "https://alertmanager.url.com",
+					GrafanaPublicURL:      "https://grafana.url.com",
+					PrometheusPublicURL:   "https://prometheus.url.com",
+					ThanosPublicURL:       "https://thanos.url.com",
+				},
+				Auth: Auth{
+					ClientID:            api.OpenShiftConsoleName,
+					ClientSecretFile:    clientSecretFilePath,
+					OAuthEndpointCAFile: defaultIngressCertFilePath,
 					LogoutRedirect:      "https://foobar.com/logout",
 				},
 				Customization: Customization{},
@@ -192,6 +241,7 @@ providers: {}
 					APIServerURL("https://foobar.com/api").
 					Host("https://foobar.com/host").
 					LogoutURL("https://foobar.com/logout").
+					DefaultIngressCert(false).
 					ConfigYAML()
 			},
 			output: `apiVersion: console.openshift.io/v1
@@ -206,10 +256,52 @@ clusterInfo:
 auth:
   clientID: console
   clientSecretFile: /var/oauth-config/clientSecret
-  oauthEndpointCAFile: /var/run/secrets/kubernetes.io/serviceaccount/ca.crt
+  oauthEndpointCAFile: /var/default-ingress-cert/ca-bundle.crt
   logoutRedirect: https://foobar.com/logout
 customization: {}
 providers: {}
+`,
+		},
+		{
+			name: "Config builder should handle monitoring and info",
+			input: func() ([]byte, error) {
+				b := &ConsoleServerCLIConfigBuilder{}
+				return b.
+					APIServerURL("https://foobar.com/api").
+					Host("https://foobar.com/host").
+					LogoutURL("https://foobar.com/logout").
+					Monitoring(&corev1.ConfigMap{
+						Data: map[string]string{
+							"alertmanagerPublicURL": "https://alertmanager.url.com",
+							"grafanaPublicURL":      "https://grafana.url.com",
+							"prometheusPublicURL":   "https://prometheus.url.com",
+							"thanosPublicURL":       "https://thanos.url.com",
+						},
+					}).
+					DefaultIngressCert(false).
+					ConfigYAML()
+			},
+			output: `apiVersion: console.openshift.io/v1
+kind: ConsoleConfig
+servingInfo:
+  bindAddress: https://[::]:8443
+  certFile: /var/serving-cert/tls.crt
+  keyFile: /var/serving-cert/tls.key
+clusterInfo:
+  consoleBaseAddress: https://foobar.com/host
+  masterPublicURL: https://foobar.com/api
+auth:
+  clientID: console
+  clientSecretFile: /var/oauth-config/clientSecret
+  oauthEndpointCAFile: /var/default-ingress-cert/ca-bundle.crt
+  logoutRedirect: https://foobar.com/logout
+customization: {}
+providers: {}
+monitoringInfo:
+  alertmanagerPublicURL: https://alertmanager.url.com
+  grafanaPublicURL: https://grafana.url.com
+  prometheusPublicURL: https://prometheus.url.com
+  thanosPublicURL: https://thanos.url.com
 `,
 		},
 		{
@@ -243,7 +335,16 @@ providers:
 					Brand(v1.BrandOKD).
 					DocURL("https://foobar.com/docs").
 					APIServerURL("https://foobar.com/api").
-					StatusPageID("status-12345")
+					StatusPageID("status-12345").
+					Monitoring(&corev1.ConfigMap{
+						Data: map[string]string{
+							"alertmanagerPublicURL": "https://alertmanager.url.com",
+							"grafanaPublicURL":      "https://grafana.url.com",
+							"prometheusPublicURL":   "https://prometheus.url.com",
+							"thanosPublicURL":       "https://thanos.url.com",
+						},
+					}).
+					DefaultIngressCert(true)
 				return b.ConfigYAML()
 			},
 			output: `apiVersion: console.openshift.io/v1
@@ -264,6 +365,11 @@ customization:
   documentationBaseURL: https://foobar.com/docs
 providers:
   statuspageID: status-12345
+monitoringInfo:
+  alertmanagerPublicURL: https://alertmanager.url.com
+  grafanaPublicURL: https://grafana.url.com
+  prometheusPublicURL: https://prometheus.url.com
+  thanosPublicURL: https://thanos.url.com
 `,
 		},
 	}
